@@ -52,17 +52,17 @@ class IntelliOpsOpenFgaSDK:
         """
         Initializes the datasource for FGA.
         Args:
-            create_fga_model (CreateDataSourceModel): The model containing the necessary parameters.
+            create_datasource_model (CreateDataSourceModel): The model containing the necessary parameters.
         Returns:
             None
         Raises:
             httpx.HTTPStatusError: If the response status is not 2xx.
             httpx.RequestError: For network-related errors.
         """
-        init_datasource_endpoint = "auth/sync"
+        init_datasource_endpoint = "/auth/sync"
         try:
             response = self.http_client.post(
-                init_datasource_endpoint, json=create_datasource_model.model_dump_json()
+                init_datasource_endpoint, json=create_datasource_model.model_dump()
             )
             response.raise_for_status()
         except httpx.HTTPStatusError as exc:
@@ -75,17 +75,11 @@ class IntelliOpsOpenFgaSDK:
     ) -> None:
         """
         Asynchronously initializes the datasource for FGA.
-        Args:
-            create_datasource_model (CreateDataSourceModel): The model containing the necessary parameters.
-        Returns:
-            None
-        Raises:
-            RuntimeError: If an HTTP or network error occurs.
         """
-        init_datasource_endpoint = "auth/sync"
+        init_datasource_endpoint = "/auth/sync"
         try:
             response = await self.http_client.async_post(
-                init_datasource_endpoint, json=create_datasource_model.model_dump_json()
+                init_datasource_endpoint, json=create_datasource_model.model_dump()
             )
             response.raise_for_status()
         except httpx.HTTPStatusError as exc:
@@ -96,20 +90,10 @@ class IntelliOpsOpenFgaSDK:
     def __init_fga(self, create_fga_model: CreateFgaModel) -> None:
         """
         Creates a new FGA model.
-        Args:
-            model_name (str): The name of the model to create.
-            model_definition (dict): The definition of the model.
-        Returns:
-            dict: The response from the FGA service.
-        Raises:
-            httpx.HTTPStatusError: If the response status is not 2xx.
-            httpx.RequestError: For network-related errors.
         """
-        create_groups_endpoint = "confluence/create-groups"
-        create_l1_l2_objects_endpoint = "confluence/create-l1-l2-objects"
-
+        create_groups_endpoint = "/confluence/create-groups"
+        create_l1_l2_objects_endpoint = "/confluence/create-l1-l2-objects"
         try:
-            # Create groups
             create_groups_model: CreateGroupsModel = CreateGroupsModel(
                 intelliopsTenantUId=create_fga_model.intelliopsTenantUId,
                 intelliopsUserUId=create_fga_model.intelliopsUserUId,
@@ -118,11 +102,9 @@ class IntelliOpsOpenFgaSDK:
                 refreshToken=create_fga_model.refreshToken,
             )
             create_groups_model_response = self.http_client.post(
-                create_groups_endpoint, json=create_groups_model.model_dump_json()
+                create_groups_endpoint, json=create_groups_model.model_dump()
             )
             create_groups_model_response.raise_for_status()
-
-            # Create L1 and L2 objects
             create_l1_l2_objects_model: CreateL1L2ObjectsModel = CreateL1L2ObjectsModel(
                 intelliopsUserUId=create_fga_model.intelliopsUserUId,
                 intelliopsTenantUId=create_fga_model.intelliopsTenantUId,
@@ -132,7 +114,7 @@ class IntelliOpsOpenFgaSDK:
                 refreshToken=create_fga_model.refreshToken,
             )
             create_l1_l2_objects_model_response = self.http_client.post(
-                create_l1_l2_objects_endpoint, json=create_l1_l2_objects_model.model_dump_json()
+                create_l1_l2_objects_endpoint, json=create_l1_l2_objects_model.model_dump()
             )
             create_l1_l2_objects_model_response.raise_for_status()
         except httpx.HTTPStatusError as exc:
@@ -143,15 +125,9 @@ class IntelliOpsOpenFgaSDK:
     async def __async_init_fga(self, create_fga_model: CreateFgaModel) -> None:
         """
         Asynchronously creates a new FGA model.
-        Args:
-            create_fga_model (CreateFgaModel): The model containing the necessary parameters.
-        Returns:
-            None
-        Raises:
-            RuntimeError: If an HTTP or network error occurs.
         """
-        create_groups_endpoint = "confluence/create-groups"
-        create_l1_l2_objects_endpoint = "confluence/create-l1-l2-objects"
+        create_groups_endpoint = "/confluence/create-groups"
+        create_l1_l2_objects_endpoint = "/confluence/create-l1-l2-objects"
         try:
             create_groups_model: CreateGroupsModel = CreateGroupsModel(
                 intelliopsTenantUId=create_fga_model.intelliopsTenantUId,
@@ -161,7 +137,7 @@ class IntelliOpsOpenFgaSDK:
                 refreshToken=create_fga_model.refreshToken,
             )
             create_groups_model_response = await self.http_client.async_post(
-                create_groups_endpoint, json=create_groups_model.model_dump_json()
+                create_groups_endpoint, json=create_groups_model.model_dump()
             )
             create_groups_model_response.raise_for_status()
             create_l1_l2_objects_model: CreateL1L2ObjectsModel = CreateL1L2ObjectsModel(
@@ -173,7 +149,7 @@ class IntelliOpsOpenFgaSDK:
                 refreshToken=create_fga_model.refreshToken,
             )
             create_l1_l2_objects_model_response = await self.http_client.async_post(
-                create_l1_l2_objects_endpoint, json=create_l1_l2_objects_model.model_dump_json()
+                create_l1_l2_objects_endpoint, json=create_l1_l2_objects_model.model_dump()
             )
             create_l1_l2_objects_model_response.raise_for_status()
         except httpx.HTTPStatusError as exc:
@@ -184,20 +160,12 @@ class IntelliOpsOpenFgaSDK:
     def check_access(self, check_access_model: CheckAccessModel) -> bool:
         """
         Checks access for the user.
-        Returns:
-            bool: True if the user has access, False otherwise.
-        Raises:
-            httpx.HTTPStatusError: If the response status is not 2xx.
-            httpx.RequestError: For network-related errors.
         """
-        check_access_endpoint = "access/check"
+        check_access_endpoint = "/access/check"
         try:
             response = self.http_client.post(
                 check_access_endpoint,
-                json={
-                    "user_id": check_access_model.intelliopsUserUId,
-                    "l2_object_id": check_access_model.fgaObjectId,
-                },
+                json=check_access_model.model_dump(),
             )
             response.raise_for_status()
             hasAccess = response.json().get("hasAccess", False)
@@ -210,22 +178,12 @@ class IntelliOpsOpenFgaSDK:
     async def async_check_access(self, check_access_model: CheckAccessModel) -> bool:
         """
         Asynchronously checks access for the user.
-        Args:
-            user_id (str): The user identifier.
-            l2_object_id (str): The L2 object identifier.
-        Returns:
-            bool: True if the user has access, False otherwise.
-        Raises:
-            RuntimeError: If an HTTP or network error occurs.
         """
-        check_access_endpoint = "access/check"
+        check_access_endpoint = "/access/check"
         try:
             response = await self.http_client.async_post(
                 check_access_endpoint,
-                json={
-                    "user_id": check_access_model.intelliopsUserUId,
-                    "l2_object_id": check_access_model.fgaObjectId,
-                },
+                json=check_access_model.model_dump(),
             )
             response.raise_for_status()
             return response.json().get("hasAccess", False)
@@ -235,31 +193,23 @@ class IntelliOpsOpenFgaSDK:
             self._handle_request_error(exc)
 
     def check_multi_access(
-        self, check_access_model: CheckMultipleAccessModel
+        self, check_multi_access_model: CheckMultipleAccessModel
     ) -> Dict[str, bool]:
         """
         Checks access for the user.
-        Returns:
-            bool: True if the user has access, False otherwise.
-        Raises:
-            httpx.HTTPStatusError: If the response status is not 2xx.
-            httpx.RequestError: For network-related errors.
         """
-        check_multi_access_endpoint = "access/multi-check"
+        check_multi_access_endpoint = "/access/multi-check"
         try:
             response = self.http_client.post(
                 check_multi_access_endpoint,
-                json={
-                    "user_id": check_access_model.intelliopsUserUId,
-                    "l2_object_id": check_access_model.fgaObjectIds,
-                },
+                json=check_multi_access_model.model_dump(),
             )
             response.raise_for_status()
             res = response.json()
             return {
                 item["l2object"].split("_")[-1]: item["hasAccess"]
-                for item in res["results"]["results"]
-            }  # Output: {'550568177': True, '669876453': False, '190480451': True}
+                for item in res["results"]
+            }
         except httpx.HTTPStatusError as exc:
             self._handle_http_error(exc)
         except httpx.RequestError as exc:
@@ -270,27 +220,19 @@ class IntelliOpsOpenFgaSDK:
     ) -> Dict[str, bool]:
         """
         Checks access for the user.
-        Returns:
-            bool: True if the user has access, False otherwise.
-        Raises:
-            httpx.HTTPStatusError: If the response status is not 2xx.
-            httpx.RequestError: For network-related errors.
         """
-        check_multi_access_endpoint = "access/multi-check"
+        check_multi_access_endpoint = "/access/multi-check"
         try:
             response = await self.http_client.async_post(
                 check_multi_access_endpoint,
-                json={
-                    "user_id": check_access_model.intelliopsUserUId,
-                    "l2_object_id": check_access_model.fgaObjectIds,
-                },
+                json=check_access_model.model_dump(),
             )
             response.raise_for_status()
             res = response.json()
             return {
                 item["l2object"].split("_")[-1]: item["hasAccess"]
-                for item in res["results"]["results"]
-            }  # Output: {'550568177': True, '669876453': False, '190480451': True}
+                for item in res["results"]
+            }
         except httpx.HTTPStatusError as exc:
             self._handle_http_error(exc)
         except httpx.RequestError as exc:
